import Component from '@ember/component';
import Slotted from 'block-slots';

export default Component.extend(Slotted, {
  classNames: ['healthcheck-output'],
});
